/**
 * @description Setting表单配置信息
 */
export default function (setting, hasPrimaryKey) {
  let appType = sessionStorage.getItem('appType')

  let menulist = []
  let appmenulist = []

  if (appType) {
    appmenulist = sessionStorage.getItem('appMenus')
    if (appmenulist) {
      try {
        appmenulist = JSON.parse(appmenulist)
      } catch (e) {
        appmenulist = []
      }
    } else {
      appmenulist = []
    }
  } else {
    menulist = sessionStorage.getItem('fstMenuList')
    if (menulist) {
      try {
        menulist = JSON.parse(menulist)
      } catch (e) {
        menulist = []
      }
    } else {
      menulist = []
    }
  }

  const cardSettingForm = [
    {
      type: 'number',
      field: 'width',
      label: '卡片宽度',
      initval: setting.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'radio',
      field: 'type',
      label: '卡片类型',
      initval: setting.type || 'simple',
      tooltip: '选择复式卡时，可配置鼠标悬浮时的显示信息。',
      required: false,
      options: [
        {value: 'simple', label: '单卡'},
        {value: 'multi', label: '复式卡'},
      ],
      controlFields: [
        {field: 'transform', values: ['multi']},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'select',
      field: 'transform',
      label: '过渡效果',
      initval: setting.transform || 'up',
      tooltip: '复式卡片鼠标悬浮信息的动画效果。',
      required: false,
      options: [
        {value: 'up', label: '向上滑动'},
        {value: 'down', label: '向下滑动'},
        {value: 'left', label: '向左滑动'},
        {value: 'right', label: '向右滑动'},
        {value: 'scale', label: '缩放'},
        {value: 'opacity', label: '透明度'},
        {value: 'rotateX', label: '纵向展开'},
        {value: 'rotateY', label: '横向展开'},
      ]
    },
    {
      type: 'text',
      field: 'primaryId',
      label: '主键值',
      initval: setting.primaryId || '',
      tooltip: '设置一个属性卡静态ID，向其他组件传递的指定静态ID值',
      required: false,
      forbid: !hasPrimaryKey
    },
    {
      type: 'radio',
      field: 'click',
      label: '点击事件',
      initval: setting.click || '',
      tooltip: '当选择触发按钮时，只有当卡片中只存在一个按钮时有效。',
      required: false,
      options: [
        {value: '', label: '无'},
        {value: 'menu', label: '菜单'},
        {value: 'link', label: '链接'},
        {value: 'button', label: '按钮'},
      ],
      controlFields: [
        {field: 'menu', values: ['menu']},
        {field: 'linkurl', values: ['link']},
        {field: 'open', values: ['menu', 'link']},
        {field: 'joint', values: ['menu', 'link']},
      ]
    },
    {
      type: appType ? 'select' : 'cascader',
      field: 'menu',
      label: '关联菜单',
      initval: setting.menu || (appType ? '' : []),
      required: true,
      options: appType ? appmenulist : menulist,
    },
    {
      type: 'textarea',
      field: 'linkurl',
      label: '链接',
      initval: setting.linkurl || '',
      required: true,
      options: [],
      span: 24
    },
    {
      type: 'radio',
      field: 'open',
      label: '打开方式',
      initval: setting.open || 'blank',
      required: false,
      options: [
        {value: 'blank', label: '新窗口'},
        {value: 'self', label: '当前窗口'},
      ],
      forbid: appType !== 'pc'
    },
    {
      type: 'radio',
      field: 'joint',
      label: '参数拼接',
      initval: setting.joint || 'true',
      required: false,
      options: [
        {value: 'true', label: '是'},
        {value: 'false', label: '否'},
      ],
    },
  ]

  return cardSettingForm
} 